aboutsummaryrefslogtreecommitdiffstats
path: root/tests/new
diff options
context:
space:
mode:
authorjhugunin <jhugunin>2003-01-08 01:18:02 +0000
committerjhugunin <jhugunin>2003-01-08 01:18:02 +0000
commit14783484fbcb2151328592cee51531449fc03cb0 (patch)
treeb6c370a19c4572684a2b765c525c00c673562d51 /tests/new
parent0b062880f1d6dcd5841124b381fa3dddd2bd7e64 (diff)
downloadaspectj-14783484fbcb2151328592cee51531449fc03cb0.tar.gz
aspectj-14783484fbcb2151328592cee51531449fc03cb0.zip
fixed strange dependence on a file named foo
Diffstat (limited to 'tests/new')
-rw-r--r--tests/new/MissingTypeInDeclareParents.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/new/MissingTypeInDeclareParents.java b/tests/new/MissingTypeInDeclareParents.java
index ad969a65b..a2fd4f619 100644
--- a/tests/new/MissingTypeInDeclareParents.java
+++ b/tests/new/MissingTypeInDeclareParents.java
@@ -7,8 +7,8 @@ import java.io.*;
public class MissingTypeInDeclareParents {
public static void main(String[] args) throws Exception {
- FileReader fr = new FileReader("foo");
- //fr.run();
+ FileWriter fr = new FileWriter("foo");
+ fr.close();
Tester.check(true, "Kilroy was here");
}
}
@@ -16,6 +16,6 @@ public class MissingTypeInDeclareParents {
class C {
}
aspect A {
- /** Xlint warning expected where FileReader is outside code controlled by implementation */
- declare parents : FileReader extends Runnable; // CW 20 Xlint warning
+ /** Xlint warning expected where FileWriter is outside code controlled by implementation */
+ declare parents : FileWriter extends Runnable; // CW 20 Xlint warning
}